
#undef DEBUG_ALLOC

#define HAVE_ATTRIBUTE 1

#undef HAVE_SOCKLEN_T 

#undef POLLRDNORM

#undef POLLWRNORM
